CustomAttributes

Struct CustomAttributes 

pub struct CustomAttributes { /* private fields */ }
A collection of custom attributes for a type, field, or variant.

These attributes can be created with the Reflect derive macro, or with CustomAttributesBuilder.

Attributes are stored by their TypeId. Because of this, there can only be one attribute per type.

Example

use core::ops::RangeInclusive;
#[derive(Reflect)]
struct Slider {
  #[reflect(@RangeInclusive::<f32>::new(0.0, 1.0))]
  value: f32
}

let TypeInfo::Struct(info) = <Slider as Typed>::type_info() else {
  panic!("expected struct info");
};

let range = info.field("value").unwrap().get_attribute::<RangeInclusive<f32>>().unwrap();
assert_eq!(0.0..=1.0, *range);

Implementations

Source

impl CustomAttributes

pub fn contains<T: Reflect>(&self) -> bool

Returns true if this collection contains a custom attribute of the specified type.

pub fn contains_by_id(&self, id: TypeId) -> bool

Returns true if this collection contains a custom attribute with the specified TypeId.

pub fn get<T: Reflect>(&self) -> Option<&T>

Gets a custom attribute by type.

pub fn get_by_id(&self, id: TypeId) -> Option<&dyn Reflect>

Gets a custom attribute by its TypeId.

pub fn iter(&self) -> impl Iterator<Item = (&TypeId, &dyn Reflect)>

Returns an iterator over all custom attributes.

pub fn len(&self) -> usize

Returns the number of custom attributes in this collection.

pub fn is_empty(&self) -> bool

Returns true if this collection is empty.